@@ -2,6 +2,7 @@ import json
 import logging
 import pkg_resources
 import sys
+import os
 import weakref
 import dateutil
 import dateutil.parser
@@ -13,6 +14,8 @@ import presalytics.lib.exceptions
 import presalytics.lib.constants
 import presalytics.story.outline
 import typing
+import mimetypes
+from werkzeug.datastructures import FileStorage
 if typing.TYPE_CHECKING:
     from presalytics.client.api import Client
 
@@ -119,6 +122,10 @@ class AuthenticationMixIn(object):
         super(AuthenticationMixIn, self).__init__()
         self.update_configuration()
 
+    @property
+    def api_name(self):
+        return self.configuration.host.rstrip("/").split("/")[-1]
+
     def call_api(
             self, resource_path, method,
             path_params=None, query_params=None, header_params=None,
@@ -244,9 +251,46 @@ class AuthenticationMixIn(object):
 
     @property
     def external_root_url(self):
-        if presalytics.CONFIG.get("BROWSER_API_HOST", None):
-            base_uri = self.configuration.host.rstrip("/").split("/")[-1]
-            target = presalytics.CONFIG["BROWSER_API_HOST"].rstrip("/") + "/story"
+        base_uri = self.configuration.host.rstrip("/").split("/")[-1]
+        service_key = base_uri.replace("-", "_").upper()
+        if presalytics.CONFIG.get(service_key, None):
+            service_host = presalytics.CONFIG["BROWSER_API_HOST"][service_key]
+            target = service_host.rstrip("/") + "/" + base_uri
         else:
             target = self.configuration.host
-        return target
\ No newline at end of file
+        return target
+
+
+    def files_parameters(self, files=None):
+        """Builds form parameters.
+
+        This override method expands the capabilites of codegen filehandler to
+        accept a `werkzeug.datastructures.FileStorage` object.
+
+        :param files: File parameters. Either a string file path or a `werkzeug.datastructures.FileStorage` object
+        :return: Form parameters with files.
+        """
+        params = []
+
+        if files:
+            for k, v in six.iteritems(files):
+                if not v:
+                    continue
+                if type(v) is str or type(v) is list:
+                    file_names = v if type(v) is list else [v]
+                    for n in file_names:
+                        with open(n, 'rb') as f:
+                            filename = os.path.basename(f.name)
+                            filedata = f.read()
+
+                else:
+                    if type(v) is FileStorage:
+                        filename = v.filename
+                        v.stream.seek(0)
+                        filedata = v.stream.read()
+                    else:
+                        raise AttributeError("Invalid File Object")
+                mimetype = (mimetypes.guess_type(filename)[0] or 'application/octet-stream')
+                params.append(tuple([k, tuple([filename, filedata, mimetype])]))
+
+        return params
\ No newline at end of file
